@@ -1,4 +1,3 @@
-# encoding: UTF-8
 require 'spec_helper'
 
 RSpec.describe Mysql2::Result do
@@ -27,13 +26,13 @@ RSpec.describe Mysql2::Result do
   end
 
   it "should raise a Mysql2::Error exception upon a bad query" do
-    expect {
+    expect do
       @client.query "bad sql"
-    }.to raise_error(Mysql2::Error)
+    end.to raise_error(Mysql2::Error)
 
-    expect {
+    expect do
       @client.query "SELECT 1"
-    }.not_to raise_error
+    end.not_to raise_error
   end
 
   it "should respond to #count, which is aliased as #size" do
@@ -62,13 +61,13 @@ RSpec.describe Mysql2::Result do
     end
 
     it "should yield rows as hash's with symbol keys if :symbolize_keys was set to true" do
-      @result.each(:symbolize_keys => true) do |row|
+      @result.each(symbolize_keys: true) do |row|
         expect(row.keys.first).to be_an_instance_of(Symbol)
       end
     end
 
     it "should be able to return results as an array" do
-      @result.each(:as => :array) do |row|
+      @result.each(as: :array) do |row|
         expect(row).to be_an_instance_of(Array)
       end
     end
@@ -78,60 +77,58 @@ RSpec.describe Mysql2::Result do
     end
 
     it "should not cache previously yielded results if cache_rows is disabled" do
-      result = @client.query "SELECT 1", :cache_rows => false
+      result = @client.query "SELECT 1", cache_rows: false
       expect(result.first.object_id).not_to eql(result.first.object_id)
     end
 
     it "should be able to iterate a second time even if cache_rows is disabled" do
-      result = @client.query "SELECT 1 UNION SELECT 2", :cache_rows => false
+      result = @client.query "SELECT 1 UNION SELECT 2", cache_rows: false
       expect(result.to_a).to eql(result.to_a)
     end
 
     it "should yield different value for #first if streaming" do
-      result = @client.query "SELECT 1 UNION SELECT 2", :stream => true, :cache_rows => false
+      result = @client.query "SELECT 1 UNION SELECT 2", stream: true, cache_rows: false
       expect(result.first).not_to eql(result.first)
     end
 
     it "should yield the same value for #first if streaming is disabled" do
-      result = @client.query "SELECT 1 UNION SELECT 2", :stream => false
+      result = @client.query "SELECT 1 UNION SELECT 2", stream: false
       expect(result.first).to eql(result.first)
     end
 
     it "should throw an exception if we try to iterate twice when streaming is enabled" do
-      result = @client.query "SELECT 1 UNION SELECT 2", :stream => true, :cache_rows => false
+      result = @client.query "SELECT 1 UNION SELECT 2", stream: true, cache_rows: false
 
-      expect {
+      expect do
         result.each.to_a
         result.each.to_a
-      }.to raise_exception(Mysql2::Error)
+      end.to raise_exception(Mysql2::Error)
     end
   end
 
   context "#fields" do
-    before(:each) do
-      @test_result = @client.query("SELECT * FROM mysql2_test ORDER BY id DESC LIMIT 1")
-    end
+    let(:test_result) { @client.query("SELECT * FROM mysql2_test ORDER BY id DESC LIMIT 1") }
 
     it "method should exist" do
-      expect(@test_result).to respond_to(:fields)
+      expect(test_result).to respond_to(:fields)
     end
 
     it "should return an array of field names in proper order" do
       result = @client.query "SELECT 'a', 'b', 'c'"
-      expect(result.fields).to eql(%w(a b c))
+      expect(result.fields).to eql(%w[a b c])
     end
   end
 
   context "streaming" do
     it "should maintain a count while streaming" do
-      result = @client.query('SELECT 1', :stream => true, :cache_rows => false)
+      result = @client.query('SELECT 1', stream: true, cache_rows: false)
       expect(result.count).to eql(0)
       result.each.to_a
       expect(result.count).to eql(1)
     end
 
     it "should retain the count when mixing first and each" do
-      result = @client.query("SELECT 1 UNION SELECT 2", :stream => true, :cache_rows => false)
+      result = @client.query("SELECT 1 UNION SELECT 2", stream: true, cache_rows: false)
       expect(result.count).to eql(0)
       result.first
       expect(result.count).to eql(1)
@@ -140,13 +137,13 @@ RSpec.describe Mysql2::Result do
     end
 
     it "should not yield nil at the end of streaming" do
-      result = @client.query('SELECT * FROM mysql2_test', :stream => true, :cache_rows => false)
+      result = @client.query('SELECT * FROM mysql2_test', stream: true, cache_rows: false)
       result.each { |r| expect(r).not_to be_nil }
     end
 
     it "#count should be zero for rows after streaming when there were no results" do
       @client.query "USE test"
-      result = @client.query("SELECT * FROM mysql2_test WHERE null_test IS NOT NULL", :stream => true, :cache_rows => false)
+      result = @client.query("SELECT * FROM mysql2_test WHERE null_test IS NOT NULL", stream: true, cache_rows: false)
       expect(result.count).to eql(0)
       result.each.to_a
       expect(result.count).to eql(0)
@@ -162,24 +159,22 @@ RSpec.describe Mysql2::Result do
       end
 
       @client.query "SET net_write_timeout = 1"
-      res = @client.query "SELECT * FROM streamingTest", :stream => true, :cache_rows => false
+      res = @client.query "SELECT * FROM streamingTest", stream: true, cache_rows: false
 
-      expect {
+      expect do
         res.each_with_index do |_, i|
           # Exhaust the first result packet then trigger a timeout
-          sleep 2 if i > 0 && i % 1000 == 0
+          sleep 4 if i > 0 && i % 1000 == 0
         end
-      }.to raise_error(Mysql2::Error, /Lost connection/)
+      end.to raise_error(Mysql2::Error, /Lost connection/)
     end
   end
 
   context "row data type mapping" do
-    before(:each) do
-      @test_result = @client.query("SELECT * FROM mysql2_test ORDER BY id DESC LIMIT 1").first
-    end
+    let(:test_result) { @client.query("SELECT * FROM mysql2_test ORDER BY id DESC LIMIT 1").first }
 
     it "should return nil values for NULL and strings for everything else when :cast is false" do
-      result = @client.query('SELECT null_test, tiny_int_test, bool_cast_test, int_test, date_test, enum_test FROM mysql2_test WHERE bool_cast_test = 1 LIMIT 1', :cast => false).first
+      result = @client.query('SELECT null_test, tiny_int_test, bool_cast_test, int_test, date_test, enum_test FROM mysql2_test WHERE bool_cast_test = 1 LIMIT 1', cast: false).first
       expect(result["null_test"]).to be_nil
       expect(result["tiny_int_test"]).to eql("1")
       expect(result["bool_cast_test"]).to eql("1")
@@ -189,23 +184,23 @@ RSpec.describe Mysql2::Result do
     end
 
     it "should return nil for a NULL value" do
-      expect(@test_result['null_test']).to be_an_instance_of(NilClass)
-      expect(@test_result['null_test']).to eql(nil)
+      expect(test_result['null_test']).to be_an_instance_of(NilClass)
+      expect(test_result['null_test']).to eql(nil)
     end
 
     it "should return String for a BIT(64) value" do
-      expect(@test_result['bit_test']).to be_an_instance_of(String)
-      expect(@test_result['bit_test']).to eql("\000\000\000\000\000\000\000\005")
+      expect(test_result['bit_test']).to be_an_instance_of(String)
+      expect(test_result['bit_test']).to eql("\000\000\000\000\000\000\000\005")
     end
 
     it "should return String for a BIT(1) value" do
-      expect(@test_result['single_bit_test']).to be_an_instance_of(String)
-      expect(@test_result['single_bit_test']).to eql("\001")
+      expect(test_result['single_bit_test']).to be_an_instance_of(String)
+      expect(test_result['single_bit_test']).to eql("\001")
     end
 
     it "should return Fixnum for a TINYINT value" do
-      expect([Fixnum, Bignum]).to include(@test_result['tiny_int_test'].class)
-      expect(@test_result['tiny_int_test']).to eql(1)
+      expect(num_classes).to include(test_result['tiny_int_test'].class)
+      expect(test_result['tiny_int_test']).to eql(1)
     end
 
     context "cast booleans for TINYINT if :cast_booleans is enabled" do
@@ -220,9 +215,9 @@ RSpec.describe Mysql2::Result do
       end
 
       it "should return TrueClass or FalseClass for a TINYINT value if :cast_booleans is enabled" do
-        result1 = @client.query "SELECT bool_cast_test FROM mysql2_test WHERE id = #{id1} LIMIT 1", :cast_booleans => true
-        result2 = @client.query "SELECT bool_cast_test FROM mysql2_test WHERE id = #{id2} LIMIT 1", :cast_booleans => true
-        result3 = @client.query "SELECT bool_cast_test FROM mysql2_test WHERE id = #{id3} LIMIT 1", :cast_booleans => true
+        result1 = @client.query "SELECT bool_cast_test FROM mysql2_test WHERE id = #{id1} LIMIT 1", cast_booleans: true
+        result2 = @client.query "SELECT bool_cast_test FROM mysql2_test WHERE id = #{id2} LIMIT 1", cast_booleans: true
+        result3 = @client.query "SELECT bool_cast_test FROM mysql2_test WHERE id = #{id3} LIMIT 1", cast_booleans: true
         expect(result1.first['bool_cast_test']).to be true
         expect(result2.first['bool_cast_test']).to be false
         expect(result3.first['bool_cast_test']).to be true
@@ -240,147 +235,86 @@ RSpec.describe Mysql2::Result do
       end
 
       it "should return TrueClass or FalseClass for a BIT(1) value if :cast_booleans is enabled" do
-        result1 = @client.query "SELECT single_bit_test FROM mysql2_test WHERE id = #{id1}", :cast_booleans => true
-        result2 = @client.query "SELECT single_bit_test FROM mysql2_test WHERE id = #{id2}", :cast_booleans => true
+        result1 = @client.query "SELECT single_bit_test FROM mysql2_test WHERE id = #{id1}", cast_booleans: true
+        result2 = @client.query "SELECT single_bit_test FROM mysql2_test WHERE id = #{id2}", cast_booleans: true
         expect(result1.first['single_bit_test']).to be true
         expect(result2.first['single_bit_test']).to be false
       end
     end
 
     it "should return Fixnum for a SMALLINT value" do
-      expect([Fixnum, Bignum]).to include(@test_result['small_int_test'].class)
-      expect(@test_result['small_int_test']).to eql(10)
+      expect(num_classes).to include(test_result['small_int_test'].class)
+      expect(test_result['small_int_test']).to eql(10)
     end
 
     it "should return Fixnum for a MEDIUMINT value" do
-      expect([Fixnum, Bignum]).to include(@test_result['medium_int_test'].class)
-      expect(@test_result['medium_int_test']).to eql(10)
+      expect(num_classes).to include(test_result['medium_int_test'].class)
+      expect(test_result['medium_int_test']).to eql(10)
     end
 
     it "should return Fixnum for an INT value" do
-      expect([Fixnum, Bignum]).to include(@test_result['int_test'].class)
-      expect(@test_result['int_test']).to eql(10)
+      expect(num_classes).to include(test_result['int_test'].class)
+      expect(test_result['int_test']).to eql(10)
     end
 
     it "should return Fixnum for a BIGINT value" do
-      expect([Fixnum, Bignum]).to include(@test_result['big_int_test'].class)
-      expect(@test_result['big_int_test']).to eql(10)
+      expect(num_classes).to include(test_result['big_int_test'].class)
+      expect(test_result['big_int_test']).to eql(10)
     end
 
     it "should return Fixnum for a YEAR value" do
-      expect([Fixnum, Bignum]).to include(@test_result['year_test'].class)
-      expect(@test_result['year_test']).to eql(2009)
+      expect(num_classes).to include(test_result['year_test'].class)
+      expect(test_result['year_test']).to eql(2009)
     end
 
     it "should return BigDecimal for a DECIMAL value" do
-      expect(@test_result['decimal_test']).to be_an_instance_of(BigDecimal)
-      expect(@test_result['decimal_test']).to eql(10.3)
+      expect(test_result['decimal_test']).to be_an_instance_of(BigDecimal)
+      expect(test_result['decimal_test']).to eql(10.3)
     end
 
     it "should return Float for a FLOAT value" do
-      expect(@test_result['float_test']).to be_an_instance_of(Float)
-      expect(@test_result['float_test']).to eql(10.3)
+      expect(test_result['float_test']).to be_an_instance_of(Float)
+      expect(test_result['float_test']).to eql(10.3)
     end
 
     it "should return Float for a DOUBLE value" do
-      expect(@test_result['double_test']).to be_an_instance_of(Float)
-      expect(@test_result['double_test']).to eql(10.3)
+      expect(test_result['double_test']).to be_an_instance_of(Float)
+      expect(test_result['double_test']).to eql(10.3)
     end
 
     it "should return Time for a DATETIME value when within the supported range" do
-      expect(@test_result['date_time_test']).to be_an_instance_of(Time)
-      expect(@test_result['date_time_test'].strftime("%Y-%m-%d %H:%M:%S")).to eql('2010-04-04 11:44:00')
+      expect(test_result['date_time_test']).to be_an_instance_of(Time)
+      expect(test_result['date_time_test'].strftime("%Y-%m-%d %H:%M:%S")).to eql('2010-04-04 11:44:00')
     end
 
-    it "should return Time values with microseconds" do
-      now = Time.now
-      if RUBY_VERSION =~ /1.8/ || @client.server_info[:id] / 100 < 506
-        result = @client.query("SELECT CAST('#{now.strftime('%F %T %z')}' AS DATETIME) AS a")
-        expect(result.first['a'].strftime('%F %T %z')).to eql(now.strftime('%F %T %z'))
-      else
-        result = @client.query("SELECT CAST('#{now.strftime('%F %T.%6N %z')}' AS DATETIME(6)) AS a")
-        # microseconds is 6 digits after the decimal, but only test on 5 significant figures
-        expect(result.first['a'].strftime('%F %T.%5N %z')).to eql(now.strftime('%F %T.%5N %z'))
-      end
+    it "should return Time when timestamp is < 1901-12-13 20:45:52" do
+      r = @client.query("SELECT CAST('1901-12-13 20:45:51' AS DATETIME) as test")
+      expect(r.first['test']).to be_an_instance_of(Time)
     end
 
-    it "should return DateTime values with microseconds" do
-      now = DateTime.now
-      if RUBY_VERSION =~ /1.8/ || @client.server_info[:id] / 100 < 506
-        result = @client.query("SELECT CAST('#{now.strftime('%F %T %z')}' AS DATETIME)  AS a")
-        expect(result.first['a'].strftime('%F %T %z')).to eql(now.strftime('%F %T %z'))
-      else
-        result = @client.query("SELECT CAST('#{now.strftime('%F %T.%6N %z')}' AS DATETIME(6)) AS a")
-        # microseconds is 6 digits after the decimal, but only test on 5 significant figures
-        expect(result.first['a'].strftime('%F %T.%5N %z')).to eql(now.strftime('%F %T.%5N %z'))
-      end
-    end
-
-    if 1.size == 4 # 32bit
-      klass = if RUBY_VERSION =~ /1.8/
-        DateTime
-      else
-        Time
-      end
-
-      it "should return DateTime when timestamp is < 1901-12-13 20:45:52" do
-        # 1901-12-13T20:45:52 is the min for 32bit Ruby 1.8
-        r = @client.query("SELECT CAST('1901-12-13 20:45:51' AS DATETIME) as test")
-        expect(r.first['test']).to be_an_instance_of(klass)
-      end
-
-      it "should return DateTime when timestamp is > 2038-01-19T03:14:07" do
-        # 2038-01-19T03:14:07 is the max for 32bit Ruby 1.8
-        r = @client.query("SELECT CAST('2038-01-19 03:14:08' AS DATETIME) as test")
-        expect(r.first['test']).to be_an_instance_of(klass)
-      end
-    elsif 1.size == 8 # 64bit
-      if RUBY_VERSION =~ /1.8/
-        it "should return Time when timestamp is > 0138-12-31 11:59:59" do
-          r = @client.query("SELECT CAST('0139-1-1 00:00:00' AS DATETIME) as test")
-          expect(r.first['test']).to be_an_instance_of(Time)
-        end
-
-        it "should return DateTime when timestamp is < 0139-1-1T00:00:00" do
-          r = @client.query("SELECT CAST('0138-12-31 11:59:59' AS DATETIME) as test")
-          expect(r.first['test']).to be_an_instance_of(DateTime)
-        end
-
-        it "should return Time when timestamp is > 2038-01-19T03:14:07" do
-          r = @client.query("SELECT CAST('2038-01-19 03:14:08' AS DATETIME) as test")
-          expect(r.first['test']).to be_an_instance_of(Time)
-        end
-      else
-        it "should return Time when timestamp is < 1901-12-13 20:45:52" do
-          r = @client.query("SELECT CAST('1901-12-13 20:45:51' AS DATETIME) as test")
-          expect(r.first['test']).to be_an_instance_of(Time)
-        end
-
-        it "should return Time when timestamp is > 2038-01-19T03:14:07" do
-          r = @client.query("SELECT CAST('2038-01-19 03:14:08' AS DATETIME) as test")
-          expect(r.first['test']).to be_an_instance_of(Time)
-        end
-      end
+    it "should return Time when timestamp is > 2038-01-19T03:14:07" do
+      r = @client.query("SELECT CAST('2038-01-19 03:14:08' AS DATETIME) as test")
+      expect(r.first['test']).to be_an_instance_of(Time)
     end
 
     it "should return Time for a TIMESTAMP value when within the supported range" do
-      expect(@test_result['timestamp_test']).to be_an_instance_of(Time)
-      expect(@test_result['timestamp_test'].strftime("%Y-%m-%d %H:%M:%S")).to eql('2010-04-04 11:44:00')
+      expect(test_result['timestamp_test']).to be_an_instance_of(Time)
+      expect(test_result['timestamp_test'].strftime("%Y-%m-%d %H:%M:%S")).to eql('2010-04-04 11:44:00')
     end
 
     it "should return Time for a TIME value" do
-      expect(@test_result['time_test']).to be_an_instance_of(Time)
-      expect(@test_result['time_test'].strftime("%Y-%m-%d %H:%M:%S")).to eql('2000-01-01 11:44:00')
+      expect(test_result['time_test']).to be_an_instance_of(Time)
+      expect(test_result['time_test'].strftime("%Y-%m-%d %H:%M:%S")).to eql('2000-01-01 11:44:00')
     end
 
     it "should return Date for a DATE value" do
-      expect(@test_result['date_test']).to be_an_instance_of(Date)
-      expect(@test_result['date_test'].strftime("%Y-%m-%d")).to eql('2010-04-04')
+      expect(test_result['date_test']).to be_an_instance_of(Date)
+      expect(test_result['date_test'].strftime("%Y-%m-%d")).to eql('2010-04-04')
     end
 
     it "should return String for an ENUM value" do
-      expect(@test_result['enum_test']).to be_an_instance_of(String)
-      expect(@test_result['enum_test']).to eql('val1')
+      expect(test_result['enum_test']).to be_an_instance_of(String)
+      expect(test_result['enum_test']).to eql('val1')
     end
 
     it "should raise an error given an invalid DATETIME" do
@@ -389,14 +323,12 @@ RSpec.describe Mysql2::Result do
     end
 
     context "string encoding for ENUM values" do
-      before { pending('Encoding is undefined') unless defined?(Encoding) }
-
       it "should default to the connection's encoding if Encoding.default_internal is nil" do
         with_internal_encoding nil do
           result = @client.query("SELECT * FROM mysql2_test ORDER BY id DESC LIMIT 1").first
           expect(result['enum_test'].encoding).to eql(Encoding::UTF_8)
 
-          client2 = new_client(:encoding => 'ascii')
+          client2 = new_client(encoding: 'ascii')
           result = client2.query("SELECT * FROM mysql2_test ORDER BY id DESC LIMIT 1").first
           expect(result['enum_test'].encoding).to eql(Encoding::ASCII)
         end
@@ -416,19 +348,17 @@ RSpec.describe Mysql2::Result do
     end
 
     it "should return String for a SET value" do
-      expect(@test_result['set_test']).to be_an_instance_of(String)
-      expect(@test_result['set_test']).to eql('val1,val2')
+      expect(test_result['set_test']).to be_an_instance_of(String)
+      expect(test_result['set_test']).to eql('val1,val2')
     end
 
     context "string encoding for SET values" do
-      before { pending('Encoding is undefined') unless defined?(Encoding) }
-
       it "should default to the connection's encoding if Encoding.default_internal is nil" do
         with_internal_encoding nil do
           result = @client.query("SELECT * FROM mysql2_test ORDER BY id DESC LIMIT 1").first
           expect(result['set_test'].encoding).to eql(Encoding::UTF_8)
 
-          client2 = new_client(:encoding => 'ascii')
+          client2 = new_client(encoding: 'ascii')
           result = client2.query("SELECT * FROM mysql2_test ORDER BY id DESC LIMIT 1").first
           expect(result['set_test'].encoding).to eql(Encoding::ASCII)
         end
@@ -448,13 +378,11 @@ RSpec.describe Mysql2::Result do
     end
 
     it "should return String for a BINARY value" do
-      expect(@test_result['binary_test']).to be_an_instance_of(String)
-      expect(@test_result['binary_test']).to eql("test#{"\000" * 6}")
+      expect(test_result['binary_test']).to be_an_instance_of(String)
+      expect(test_result['binary_test']).to eql("test#{"\000" * 6}")
     end
 
     context "string encoding for BINARY values" do
-      before { pending('Encoding is undefined') unless defined?(Encoding) }
-
       it "should default to binary if Encoding.default_internal is nil" do
         with_internal_encoding nil do
           result = @client.query("SELECT * FROM mysql2_test ORDER BY id DESC LIMIT 1").first
@@ -489,14 +417,12 @@ RSpec.describe Mysql2::Result do
       'long_text_test' => 'LONGTEXT',
     }.each do |field, type|
       it "should return a String for #{type}" do
-        expect(@test_result[field]).to be_an_instance_of(String)
-        expect(@test_result[field]).to eql("test")
+        expect(test_result[field]).to be_an_instance_of(String)
+        expect(test_result[field]).to eql("test")
       end
 
       context "string encoding for #{type} values" do
-        before { pending('Encoding is undefined') unless defined?(Encoding) }
-
-        if %w(VARBINARY TINYBLOB BLOB MEDIUMBLOB LONGBLOB).include?(type)
+        if %w[VARBINARY TINYBLOB BLOB MEDIUMBLOB LONGBLOB].include?(type)
           it "should default to binary if Encoding.default_internal is nil" do
             with_internal_encoding nil do
               result = @client.query("SELECT * FROM mysql2_test ORDER BY id DESC LIMIT 1").first
@@ -521,7 +447,7 @@ RSpec.describe Mysql2::Result do
               result = @client.query("SELECT * FROM mysql2_test ORDER BY id DESC LIMIT 1").first
               expect(result[field].encoding).to eql(Encoding::UTF_8)
 
-              client2 = new_client(:encoding => 'ascii')
+              client2 = new_client(encoding: 'ascii')
               result = client2.query("SELECT * FROM mysql2_test ORDER BY id DESC LIMIT 1").first
               expect(result[field].encoding).to eql(Encoding::ASCII)
             end
@@ -542,4 +468,18 @@ RSpec.describe Mysql2::Result do
       end
     end
   end
+
+  context "server flags" do
+    let(:test_result) { @client.query("SELECT * FROM mysql2_test ORDER BY null_test DESC LIMIT 1") }
+
+    it "should set a definitive value for query_was_slow" do
+      expect(test_result.server_flags[:query_was_slow]).to eql(false)
+    end
+    it "should set a definitive value for no_index_used" do
+      expect(test_result.server_flags[:no_index_used]).to eql(true)
+    end
+    it "should set a definitive value for no_good_index_used" do
+      expect(test_result.server_flags[:no_good_index_used]).to eql(false)
+    end
+  end
 end
